==> deepin-font-installer_1.0.4.orig.tar.xz: deepin-font-installer-1.0.4/deepin-font-installer/translations/deepin-font-installer_fr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="fr" version="2.1">
<context>
    <name>HomePage</name>
    <message>
        <source>Drag font file here</source>
        <translation>Glissez le fichier de la police ici</translation>
    </message>
    <message>
        <source>Select file</source>
        <translation>Sélectionnez le fichier</translation>
    </message>
</context>
<context>
    <name>ListItem</name>
    <message>
        <source>Installed</source>
        <translation>Installé</translation>
    </message>
    <message>
        <source>Other version installed: %1</source>
        <translation>Autre version installée : %1</translation>
    </message>
    <message>
        <source>Installing</source>
        <translation>Installation</translation>
    </message>
    <message>
        <source>Same version installed</source>
        <translation>Version identique installée</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Deepin Font Installer</source>
        <translation>Installateur de Police Deepin</translation>
    </message>
    <message>
        <source>Deepin Font Installer is used to install and uninstall font file for users with bulk install function.</source>
        <translation>L&apos;installateur de polices est utilisé pour permettre à l&apos;utilisateur d&apos;installer et désinstaller une ou plusieurs polices à partir de fichiers.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Deepin Font Installer</source>
        <translation>Installateur de Police Deepin</translation>
    </message>
    <message>
        <source>Bulk Install</source>
        <translation>Installation en Vrac</translation>
    </message>
</context>
<context>
    <name>MultiFilePage</name>
    <message>
        <source>Install</source>
        <translation>Installer</translation>
    </message>
    <message>
        <source>Installed successfully</source>
        <translation>Installée avec succès</translation>
    </message>
    <message>
        <source>View font directory</source>
        <translation>Afficher le répertoire des polices</translation>
    </message>
    <message>
        <source>Refreshing font cache, please wait...</source>
        <translation>Rafraîchissement du cache des polices, veuillez patienter…</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Inconnu</translation>
    </message>
</context>
<context>
    <name>SingleFilePage</name>
    <message>
        <source>Install</source>
        <translation>Installer</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <source>Reinstall</source>
        <translation>Réinstaller</translation>
    </message>
    <message>
        <source>View font directory</source>
        <translation>Voir le dictionnaire des polices</translation>
    </message>
    <message>
        <source>Style: </source>
        <translation>Style :</translation>
    </message>
    <message>
        <source>Type: </source>
        <translation>Type :</translation>
    </message>
    <message>
        <source>Version: </source>
        <translation>Version :</translation>
    </message>
    <message>
        <source>Copyright: </source>
        <translation>Copyright:</translation>
    </message>
    <message>
        <source>Description: </source>
        <translation>Description : </translation>
    </message>
    <message>
        <source>Same version installed</source>
        <translation>La même version est installée</translation>
    </message>
    <message>
        <source>Installed successfully</source>
        <translation>Installée avec succès</translation>
    </message>
    <message>
        <source>Removed successfully</source>
        <translation>Supprimée avec succès</translation>
    </message>
    <message>
        <source>Other version installed: %1</source>
        <translation>Autre version installée : %1</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Fini</translation>
    </message>
</context>
</TS>

==> deepin-font-installer_1.1.orig.tar.xz: deepin-font-installer-1.1/deepin-font-installer/translations/deepin-font-installer_fr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="fr" version="2.1">
<context>
    <name>HomePage</name>
    <message>
        <source>Drag font file here</source>
        <translation>Glissez la police d&apos;écriture ici</translation>
    </message>
    <message>
        <source>Select file</source>
        <translation>Sélectionnez le fichier</translation>
    </message>
</context>
<context>
    <name>ListItem</name>
    <message>
        <source>Installed</source>
        <translation>Installé</translation>
    </message>
    <message>
        <source>Other version installed: %1</source>
        <translation>Autre version installée : %1</translation>
    </message>
    <message>
        <source>Installing</source>
        <translation>Installation</translation>
    </message>
    <message>
        <source>Same version installed</source>
        <translation>Version identique installée</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Deepin Font Installer</source>
        <translation>Installateur de Police Deepin</translation>
    </message>
    <message>
        <source>Deepin Font Installer is used to install and uninstall font file for users with bulk install function.</source>
        <translation>L&apos;installateur de polices est utilisé pour permettre à l&apos;utilisateur d&apos;installer et désinstaller une ou plusieurs polices à partir de fichiers.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Deepin Font Installer</source>
        <translation>Installateur de Police Deepin</translation>
    </message>
    <message>
        <source>Bulk Install</source>
        <translation>Installation en Vrac</translation>
    </message>
</context>
<context>
    <name>MultiFilePage</name>
    <message>
        <source>Install</source>
        <translation>Installer</translation>
    </message>
    <message>
        <source>Installed successfully</source>
        <translation>Installée avec succès</translation>
    </message>
    <message>
        <source>View font directory</source>
        <translation>Afficher le répertoire des polices</translation>
    </message>
    <message>
        <source>Refreshing font cache, please wait...</source>
        <translation>Rafraîchissement du cache des polices, veuillez patienter…</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Inconnu</translation>
    </message>
</context>
<context>
    <name>SingleFilePage</name>
    <message>
        <source>Install</source>
        <translation>Installer</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <source>Reinstall</source>
        <translation>Réinstaller</translation>
    </message>
    <message>
        <source>View font directory</source>
        <translation>Voir le dictionnaire des polices</translation>
    </message>
    <message>
        <source>Style: </source>
        <translation>Style :</translation>
    </message>
    <message>
        <source>Type: </source>
        <translation>Type :</translation>
    </message>
    <message>
        <source>Version: </source>
        <translation>Version :</translation>
    </message>
    <message>
        <source>Copyright: </source>
        <translation>Copyright:</translation>
    </message>
    <message>
        <source>Description: </source>
        <translation>Description : </translation>
    </message>
    <message>
        <source>Same version installed</source>
        <translation>La même version est installée</translation>
    </message>
    <message>
        <source>Installed successfully</source>
        <translation>Installée avec succès</translation>
    </message>
    <message>
        <source>Removed successfully</source>
        <translation>Supprimée avec succès</translation>
    </message>
    <message>
        <source>Other version installed: %1</source>
        <translation>Autre version installée : %1</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Terminé</translation>
    </message>
</context>
</TS>
